Documentation
¶
Index ¶
- type ApplyPatchTool
- func (t *ApplyPatchTool) Description() string
- func (t *ApplyPatchTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
- func (t *ApplyPatchTool) Name() string
- func (t *ApplyPatchTool) Parameters() map[string]interface{}
- func (t *ApplyPatchTool) ToolMetadata() toolcore.ToolMetadata
- type ClickTool
- type ExecCommandTool
- func (t *ExecCommandTool) Description() string
- func (t *ExecCommandTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
- func (t *ExecCommandTool) Name() string
- func (t *ExecCommandTool) Parameters() map[string]interface{}
- func (t *ExecCommandTool) ToolMetadata() toolcore.ToolMetadata
- type FinanceTool
- type FindTool
- type ImageQueryTool
- func (t *ImageQueryTool) Description() string
- func (t *ImageQueryTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
- func (t *ImageQueryTool) Name() string
- func (t *ImageQueryTool) Parameters() map[string]interface{}
- func (t *ImageQueryTool) ToolMetadata() toolcore.ToolMetadata
- type OpenTool
- type ScreenshotTool
- func (t *ScreenshotTool) Description() string
- func (t *ScreenshotTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
- func (t *ScreenshotTool) Name() string
- func (t *ScreenshotTool) Parameters() map[string]interface{}
- func (t *ScreenshotTool) ToolMetadata() toolcore.ToolMetadata
- type SportsTool
- type TimeTool
- type ViewImageTool
- func (t *ViewImageTool) Description() string
- func (t *ViewImageTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
- func (t *ViewImageTool) Name() string
- func (t *ViewImageTool) Parameters() map[string]interface{}
- func (t *ViewImageTool) ToolMetadata() toolcore.ToolMetadata
- type WeatherTool
- type WebSearchTool
- func (t *WebSearchTool) Description() string
- func (t *WebSearchTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
- func (t *WebSearchTool) Name() string
- func (t *WebSearchTool) Parameters() map[string]interface{}
- func (t *WebSearchTool) ToolMetadata() toolcore.ToolMetadata
- type WriteStdinTool
- func (t *WriteStdinTool) Description() string
- func (t *WriteStdinTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
- func (t *WriteStdinTool) Name() string
- func (t *WriteStdinTool) Parameters() map[string]interface{}
- func (t *WriteStdinTool) ToolMetadata() toolcore.ToolMetadata
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApplyPatchTool ¶
type ApplyPatchTool struct {
Command string
// contains filtered or unexported fields
}
ApplyPatchTool applies patch text to files.
func (*ApplyPatchTool) Description ¶
func (t *ApplyPatchTool) Description() string
func (*ApplyPatchTool) Execute ¶
func (t *ApplyPatchTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
func (*ApplyPatchTool) Name ¶
func (t *ApplyPatchTool) Name() string
func (*ApplyPatchTool) Parameters ¶
func (t *ApplyPatchTool) Parameters() map[string]interface{}
func (*ApplyPatchTool) ToolMetadata ¶
func (t *ApplyPatchTool) ToolMetadata() toolcore.ToolMetadata
type ClickTool ¶
type ClickTool struct{}
ClickTool resolves a link from a previously opened page reference.
func (*ClickTool) Description ¶
func (*ClickTool) Execute ¶
func (t *ClickTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
func (*ClickTool) Parameters ¶
func (*ClickTool) ToolMetadata ¶
func (t *ClickTool) ToolMetadata() toolcore.ToolMetadata
type ExecCommandTool ¶
type ExecCommandTool struct{}
ExecCommandTool executes a shell command.
func (*ExecCommandTool) Description ¶
func (t *ExecCommandTool) Description() string
func (*ExecCommandTool) Execute ¶
func (t *ExecCommandTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
func (*ExecCommandTool) Name ¶
func (t *ExecCommandTool) Name() string
func (*ExecCommandTool) Parameters ¶
func (t *ExecCommandTool) Parameters() map[string]interface{}
func (*ExecCommandTool) ToolMetadata ¶
func (t *ExecCommandTool) ToolMetadata() toolcore.ToolMetadata
type FinanceTool ¶
FinanceTool retrieves market quote data by ticker symbol.
func (*FinanceTool) Description ¶
func (t *FinanceTool) Description() string
func (*FinanceTool) Execute ¶
func (t *FinanceTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
func (*FinanceTool) Name ¶
func (t *FinanceTool) Name() string
func (*FinanceTool) Parameters ¶
func (t *FinanceTool) Parameters() map[string]interface{}
func (*FinanceTool) ToolMetadata ¶
func (t *FinanceTool) ToolMetadata() toolcore.ToolMetadata
type FindTool ¶
type FindTool struct{}
FindTool searches a text pattern inside previously opened page content.
func (*FindTool) Description ¶
func (*FindTool) Execute ¶
func (t *FindTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
func (*FindTool) Parameters ¶
func (*FindTool) ToolMetadata ¶
func (t *FindTool) ToolMetadata() toolcore.ToolMetadata
type ImageQueryTool ¶
ImageQueryTool searches image results for a text query.
func (*ImageQueryTool) Description ¶
func (t *ImageQueryTool) Description() string
func (*ImageQueryTool) Execute ¶
func (t *ImageQueryTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
func (*ImageQueryTool) Name ¶
func (t *ImageQueryTool) Name() string
func (*ImageQueryTool) Parameters ¶
func (t *ImageQueryTool) Parameters() map[string]interface{}
func (*ImageQueryTool) ToolMetadata ¶
func (t *ImageQueryTool) ToolMetadata() toolcore.ToolMetadata
type OpenTool ¶
OpenTool fetches content from a URL.
func (*OpenTool) Description ¶
func (*OpenTool) Execute ¶
func (t *OpenTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
func (*OpenTool) Parameters ¶
func (*OpenTool) ToolMetadata ¶
func (t *OpenTool) ToolMetadata() toolcore.ToolMetadata
type ScreenshotTool ¶
type ScreenshotTool struct {
Client *http.Client
Renderer string
// contains filtered or unexported fields
}
ScreenshotTool renders a PDF page to PNG.
func (*ScreenshotTool) Description ¶
func (t *ScreenshotTool) Description() string
func (*ScreenshotTool) Execute ¶
func (t *ScreenshotTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
func (*ScreenshotTool) Name ¶
func (t *ScreenshotTool) Name() string
func (*ScreenshotTool) Parameters ¶
func (t *ScreenshotTool) Parameters() map[string]interface{}
func (*ScreenshotTool) ToolMetadata ¶
func (t *ScreenshotTool) ToolMetadata() toolcore.ToolMetadata
type SportsTool ¶
SportsTool retrieves standings and schedule information by league.
func (*SportsTool) Description ¶
func (t *SportsTool) Description() string
func (*SportsTool) Execute ¶
func (t *SportsTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
func (*SportsTool) Name ¶
func (t *SportsTool) Name() string
func (*SportsTool) Parameters ¶
func (t *SportsTool) Parameters() map[string]interface{}
func (*SportsTool) ToolMetadata ¶
func (t *SportsTool) ToolMetadata() toolcore.ToolMetadata
type TimeTool ¶
type TimeTool struct{}
TimeTool returns the current time.
func (*TimeTool) Description ¶
func (*TimeTool) Execute ¶
func (t *TimeTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
func (*TimeTool) Parameters ¶
func (*TimeTool) ToolMetadata ¶
func (t *TimeTool) ToolMetadata() toolcore.ToolMetadata
type ViewImageTool ¶
type ViewImageTool struct{}
ViewImageTool reads local image metadata from disk.
func (*ViewImageTool) Description ¶
func (t *ViewImageTool) Description() string
func (*ViewImageTool) Execute ¶
func (t *ViewImageTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
func (*ViewImageTool) Name ¶
func (t *ViewImageTool) Name() string
func (*ViewImageTool) Parameters ¶
func (t *ViewImageTool) Parameters() map[string]interface{}
func (*ViewImageTool) ToolMetadata ¶
func (t *ViewImageTool) ToolMetadata() toolcore.ToolMetadata
type WeatherTool ¶
WeatherTool fetches weather data by location.
func (*WeatherTool) Description ¶
func (t *WeatherTool) Description() string
func (*WeatherTool) Execute ¶
func (t *WeatherTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
func (*WeatherTool) Name ¶
func (t *WeatherTool) Name() string
func (*WeatherTool) Parameters ¶
func (t *WeatherTool) Parameters() map[string]interface{}
func (*WeatherTool) ToolMetadata ¶
func (t *WeatherTool) ToolMetadata() toolcore.ToolMetadata
type WebSearchTool ¶
func (*WebSearchTool) Description ¶
func (t *WebSearchTool) Description() string
func (*WebSearchTool) Execute ¶
func (t *WebSearchTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
func (*WebSearchTool) Name ¶
func (t *WebSearchTool) Name() string
func (*WebSearchTool) Parameters ¶
func (t *WebSearchTool) Parameters() map[string]interface{}
func (*WebSearchTool) ToolMetadata ¶
func (t *WebSearchTool) ToolMetadata() toolcore.ToolMetadata
type WriteStdinTool ¶
type WriteStdinTool struct{}
WriteStdinTool writes to an interactive exec_command session and polls output.
func (*WriteStdinTool) Description ¶
func (t *WriteStdinTool) Description() string
func (*WriteStdinTool) Execute ¶
func (t *WriteStdinTool) Execute(ctx context.Context, input json.RawMessage) (json.RawMessage, error)
func (*WriteStdinTool) Name ¶
func (t *WriteStdinTool) Name() string
func (*WriteStdinTool) Parameters ¶
func (t *WriteStdinTool) Parameters() map[string]interface{}
func (*WriteStdinTool) ToolMetadata ¶
func (t *WriteStdinTool) ToolMetadata() toolcore.ToolMetadata